# MaVaTS

MaVaTS is a Python library for matrix-valued time series methods.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install MaVaTS.

```bash
pip install mavats
```

## Usage

Please refer to the [documentation](https://dx-li.github.io/MaVaTS/mavats.html)

## Contributing

Pull requests are welcome.

## License

[MIT](https://github.com/dx-li/MaVaTS/blob/main/LICENSE)